@@ -11,6 +11,11 @@
 #'   vector or nested list (fromJSON) object. By default,
 #'   \code{parse = TRUE} saves you the time [and frustrations]
 #'   associated with disentangling the Twitter API return objects.
+#' @param as_double logical indicating whether to handle ID variables
+#'   as double (numeric) class. By default, this is set to FALSE, meaning
+#'   ID variables are treated as character vectors. Setting this to
+#'   TRUE can provide performance (speed and memory) boost but can also
+#'   lead to issues when printing and saving, depending on the format.
 #' @param token OAuth token. By default \code{token = NULL} fetches a
 #'   non-exhausted token from an environment variable. Find instructions
 #'   on how to create tokens and setup an environment variable in the
@@ -34,11 +39,11 @@
 #' @family ids
 #' @export
 get_followers <- function(user, n = 75000, page = "-1", parse = TRUE,
-                          token = NULL) {
+                          as_double = FALSE, token = NULL) {
 
   query <- "followers/ids"
 
-  if (n == "all") {
+  if (identical(n, "all")) {
     n <- 75000
   }
 
@@ -63,11 +68,11 @@ get_followers <- function(user, n = 75000, page = "-1", parse = TRUE,
     query = query,
     param = params)
 
-  f <- scroller(url, n, n.times, token)
+  f <- scroller(url, n, n.times, type = NULL, token)
 
-  f <- f[!sapply(f, is.null)]
+  f <- f[!unlist(lapply(f, is.null), use.names = FALSE)]
 
-  if (parse) f <- parse_fs(f, n)
+  if (parse) f <- parse_fs(f, n, as_double = as_double)
 
   f
 }
