@@ -8,25 +8,32 @@
 #'   \code{token = NULL} fetches a non-exhausted token from
 #'   an environment variable @describeIn tokens.
 #' @param parse Logical, indicating whether or not to parse
-#'   return object into data frame(s)
+#'   return object into data frame(s).
+#' @param clean_tweets logical indicating whether to remove non-ASCII
+#'   characters in text of tweets. defaults to FALSE.
+#' @param as_double logical indicating whether to handle ID variables
+#'   as double (numeric) class. By default, this is set to FALSE, meaning
+#'   ID variables are treated as character vectors. Setting this to
+#'   TRUE can provide performance (speed and memory) boost but can also
+#'   lead to issues when printing and saving, depending on the format.
 #' @seealso \url{https://dev.twitter.com/overview/documentation}
 #' @examples
 #' \dontrun{
-#' # lookup vector of 1 or more user_id or screen_name
-#' statuses <- c("potus", "hillaryclinton", "realdonaldtrump",
-#'   "fivethirtyeight", "cnn", "espn", "twitter")
+#' # lookup tweets data via status_id vector
+#' statuses <- c("567053242429734913", "266031293945503744",
+#'   "440322224407314432")
+#' statuses <- lookup_statuses(statuses)
+#' statuses
 #'
-#' twt_df <- lookup_statuses(statuses)
-#' twt_df
-#'
-#' # view tweet data for these statuses via tweets_data()
-#' tweets_data(twt_df)
+#' # view users data for these statuses via tweets_data()
+#' users_data(statuses)
 #' }
 #'
 #' @return json response object (max is 18000 per token)
 #' @family tweets
 #' @export
-lookup_statuses <- function(statuses, token = NULL, parse = TRUE) {
+lookup_statuses <- function(statuses, token = NULL, parse = TRUE,
+                            clean_tweets = FALSE, as_double = FALSE) {
 
   if (is.list(statuses)) {
     statuses <- unlist(statuses)
@@ -59,7 +66,7 @@ lookup_statuses <- function(statuses, token = NULL, parse = TRUE) {
   }
 
   if (parse) {
-    twt <- parser(twt)
+    twt <- parser(twt, clean_tweets = clean_tweets, as_double = as_double)
     twt <- attr_tweetusers(twt[c("tweets", "users")])
   }
 
