@@ -12,6 +12,13 @@
 #'   \code{parse = TRUE} saves users from the time
 #'   [and frustrations] associated with disentangling the Twitter
 #'   API return objects.
+#' @param clean_tweets logical indicating whether to remove non-ASCII
+#'   characters in text of tweets. defaults to FALSE.
+#' @param as_double logical indicating whether to handle ID variables
+#'   as double (numeric) class. By default, this is set to FALSE, meaning
+#'   ID variables are treated as character vectors. Setting this to
+#'   TRUE can provide performance (speed and memory) boost but can also
+#'   lead to issues when printing and saving, depending on the format.
 #' @param token OAuth token. By default \code{token = NULL} fetches a
 #'   non-exhausted token from an environment variable. Find instructions
 #'   on how to create tokens and setup an environment variable in the
@@ -42,8 +49,9 @@
 #'   the user provided.
 #' @family tweets
 #' @export
-get_timeline <- function(user, n = 200, max_id = NULL,
-  parse = TRUE, token = NULL, ...) {
+get_timeline <- function(user, n = 200, max_id = NULL, parse = TRUE,
+                         clean_tweets = FALSE, as_double = FALSE,
+                         token = NULL, ...) {
 
   query <- "statuses/user_timeline"
 
@@ -69,10 +77,10 @@ get_timeline <- function(user, n = 200, max_id = NULL,
     query = query,
     param = params)
 
-  tm <- scroller(url, n, n.times, token)
+  tm <- scroller(url, n, n.times, type = "timeline", token)
 
   if (parse) {
-    tm <- parser(tm, n)
+    tm <- parser(tm, n, clean_tweets = clean_tweets, as_double = as_double)
     tm <- attr_tweetusers(tm)
   }
 
