@@ -7,6 +7,7 @@ test_that("get_followers returns data frame with ids", {
 	f <- get_followers("HillaryClinton", n = 10000, token = token)
 
   expect_true(is.data.frame(f))
+  expect_true(identical(length(next_cursor(f)), 1L))
   expect_named(f, "ids")
-  expect_equal(nrow(f), 10000)
+  expect_gt(NROW(f), 9999)
 })
